==> dreamchess_0.1.0.orig.tar.gz: dreamchess-0.1.0/src/include/pipe_win32.h <==
/*  DreamChess
**  Copyright (C) 2004  The DreamChess project
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _PIPE_WIN32_H
#define _PIPE_WIN32_H

void pipe_win32_init(HANDLE in, HANDLE out);
/* Initializes the I/O library with handles for input and output.
** Parameters: (HANDLE) in: handle to use for input.
**             (HANDLE) out: handle to use for output.
** Returns   : (void)
*/

void pipe_win32_exit();
/* Exits the I/O library cleanly.
** Parameters: (void)
** Returns   : (void)
*/

void pipe_win32_send(char *m);
/* Sends a message through the I/O library.
** Parameters: (char *) m: Message to be sent.
** Returns   : (void)
*/

char *pipe_win32_poll();
/* Polls the I/O library for input.
** Parameters: (void)
** Returns   : (char *), Message that was read from the input handle
**                 (if any).
**             NULL, otherwise.
*/

#endif /* _PIPE_WIN32_H */

==> dreamchess_0.2.0.orig.tar.gz: dreamchess-0.2.0/src/include/pipe_win32.h <==
/*  DreamChess
**
**  DreamChess is the legal property of its developers, whose names are too
**  numerous to list here. Please refer to the COPYRIGHT file distributed
**  with this source distribution.
**
**  This program is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _PIPE_WIN32_H
#define _PIPE_WIN32_H

void pipe_win32_init(HANDLE in, HANDLE out);
/* Initializes the I/O library with handles for input and output.
** Parameters: (HANDLE) in: handle to use for input.
**             (HANDLE) out: handle to use for output.
** Returns   : (void)
*/

void pipe_win32_exit();
/* Exits the I/O library cleanly.
** Parameters: (void)
** Returns   : (void)
*/

void pipe_win32_send(const char *m);
/* Sends a message through the I/O library.
** Parameters: (char *) m: Message to be sent.
** Returns   : (void)
*/

char *pipe_win32_poll(int *error);
/* Polls the I/O library for input.
** Parameters: (void)
** Returns   : (char *), Message that was read from the input handle
**                 (if any).
**             NULL, otherwise.
*/

#endif /* _PIPE_WIN32_H */
